@@ -1,7 +1,7 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 4.3 2005/01/24 00:00:30 bkorb Exp $
+ *  $Id: agUtils.c,v 4.6 2005/11/25 19:00:27 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
@@ -21,8 +21,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 /* = = = START-STATIC-FORWARD = = = */
@@ -198,7 +198,7 @@ doOptions( int arg_ct, char** arg_vec )
 
 
 LOCAL tCC*
-getDefine( tCC* pzDefName )
+getDefine( tCC* pzDefName, ag_bool check_env )
 {
     tCC**   ppz;
     int     ct;
@@ -222,120 +222,10 @@ getDefine( tCC* pzDefName )
                 return (pzEq != NULL) ? pzEq+1 : "";
         }
     }
-    return getenv( pzDefName );
+    return check_env ? getenv( pzDefName ) : NULL;
 }
 
 
-LOCAL unsigned int
-doEscapeChar( tCC* pzIn, char* pRes )
-{
-    unsigned int  res = 1;
-
-    switch (*pRes = *pzIn++) {
-    case NUL:         /* NUL - end of input string */
-    case '\n':        /* NL  - Omit newline        */
-        return 0;
-
-    case 't':
-        *pRes = '\t'; /* TAB */
-        break;
-    case 'n':
-        *pRes = '\n'; /* NEWLINE (LineFeed) */
-        break;
-    case 'f':
-        *pRes = '\f'; /* FormFeed (NewPage) */
-        break;
-    case 'r':
-        *pRes = '\r'; /* Carriage Return    */
-        break;
-    case 'v':
-        *pRes = '\v'; /* Vertical Tab       */
-        break;
-    case 'b':
-        *pRes = '\b'; /* backspace          */
-        break;
-    case 'a':
-        *pRes = '\a'; /* Bell               */
-        break;
-
-    case 'x':         /* HEX Escape       */
-        if (isxdigit( *pzIn ))  {
-            unsigned int  val;
-            unsigned char ch = *pzIn++;
-
-            if ((ch >= 'A') && (ch <= 'F'))
-                val = 10 + (ch - 'A');
-            else if ((ch >= 'a') && (ch <= 'f'))
-                val = 10 + (ch - 'a');
-            else val = ch - '0';
-
-            ch = *pzIn;
-
-            if (! isxdigit( ch )) {
-                *pRes = val;
-                res   = 2;
-                break;
-            }
-            val <<= 4;
-            if ((ch >= 'A') && (ch <= 'F'))
-                val += 10 + (ch - 'A');
-            else if ((ch >= 'a') && (ch <= 'f'))
-                val += 10 + (ch - 'a');
-            else val += ch - '0';
-
-            res = 3;
-            *pRes = val;
-        }
-        break;
-
-    default:
-        /*
-         *  IF the character copied was an octal digit,
-         *  THEN set the output character to an octal value
-         */
-        if (isdigit( *pRes ) && (*pRes < '8'))  {
-            unsigned int  val = *pRes - '0';
-            unsigned char ch  = *pzIn++;
-
-            /*
-             *  IF the second character is *not* an octal digit,
-             *  THEN save the value and bail
-             */
-            if ((ch < '0') || (ch > '7')) {
-                *pRes = val;
-                break;
-            }
-
-            val = (val<<3) + (ch - '0');
-            ch  = *pzIn;
-            res = 2;
-
-            /*
-             *  IF the THIRD character is *not* an octal digit,
-             *  THEN save the value and bail
-             */
-            if ((ch < '0') || (ch > '7')) {
-                *pRes = val;
-                break;
-            }
-
-            /*
-             *  IF the new value would not be too large,
-             *  THEN add on the third and last character value
-             */
-            if ((val<<3) < 0xFF) {
-                val = (val<<3) + (ch - '0');
-                res = 3;
-            }
-
-            *pRes = val;
-            break;
-        }
-    }
-
-    return res;
-}
-
 /*
  *  The following routine scans over quoted text, shifting
  *  it in the process and eliminating the starting quote,
@@ -357,19 +247,9 @@ spanQuote( char* pzQte )
 
         case '\\':
             if (q != '\'') {
-                unsigned int ct = doEscapeChar( pzQte, p-1 );
-                /*
-                 *  IF the advance is zero,
-                 *  THEN we either have end of string (caught above),
-                 *       or we have an escaped new-line,
-                 *       which is to be ignored.
-                 *  ELSE advance the quote scanning pointer by ct
-                 */
-                if (ct == 0) {
-                    p--;     /* move destination back one character */
-                    pzQte++; /* skip over new-line character        */
-                } else
-                    pzQte += ct;
+                int ct = ao_string_cook_escape_char(pzQte, p-1, 0x7F);
+                if (p[-1] == 0x7F)  p--;
+                pzQte += ct;
 
             } else {
                 switch (*pzQte) {
@@ -420,18 +300,8 @@ skipQuote( tCC* pzQte )
 
             } else {
                 char p[10];  /* provide a scratch pad for escape processing */
-                unsigned int ct = doEscapeChar( pzQte, p );
-                /*
-                 *  IF the advance is zero,
-                 *  THEN we either have end of string (caught above),
-                 *       or we have an escaped new-line,
-                 *       which is to be ignored.
-                 *  ELSE advance the quote scanning pointer by ct
-                 */
-                if (ct == 0) {
-                    pzQte++; /* skip over new-line character        */
-                } else
-                    pzQte += ct;
+                int ct = ao_string_cook_escape_char( pzQte, p, 0x7F );
+                pzQte += ct;
             } /* if (q == '\'')      */
         }     /* switch (*pzQte++)   */
     }         /* while (*pzQte != q) */
