@@ -1,6 +1,6 @@
 
 /*
- *  $Id: defLex.c,v 4.6 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: defLex.c,v 4.10 2005/12/04 22:26:21 bkorb Exp $
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  */
@@ -169,7 +169,7 @@ scanAgain:
             return DP_EV_INVALID;
         }
 
-        lastToken = DP_EV_STRING;
+        lastToken = DP_EV_HERE_STRING;
         pCurCtx->pzScan = pz;
         break;
     }
@@ -216,7 +216,7 @@ scanAgain:
         pCurCtx->pzScan = pz;
 
         if (pzShellProgram == NULL)
-            pzShellProgram = getDefine( zShellEnv );
+            pzShellProgram = getDefine( zShellEnv, AG_TRUE );
 
         lastToken = DP_EV_STRING;
         pz = runShell( (const char*)pz_token );
@@ -408,12 +408,12 @@ alist_to_autogen_def( void )
     /*
      *  The result *must* be a string, or we choke.
      */
-    if (! gh_string_p( res )) {
+    if (! AG_SCM_STRING_P( res )) {
         tSCC zEr[] = "Scheme definition expression does not yield string:\n";
         AG_ABEND( zEr );
     }
 
-    res_len   = SCM_LENGTH( res );
+    res_len   = AG_SCM_STRLEN( res );
     procState = PROC_STATE_LOAD_DEFS;
     pCurCtx->pzScan = pzEnd;
     AGFREE( (void*)pzText );
@@ -433,7 +433,7 @@ alist_to_autogen_def( void )
     pCtx->pzScan = \
     pCtx->pzData = (char*)(pCtx+1);
     pCtx->lineNo = 0;
-    memcpy( (void*)(pCtx->pzScan), (void*)SCM_CHARS( res ), res_len );
+    memcpy( (void*)(pCtx->pzScan), (void*)AG_SCM_CHARS( res ), res_len );
     pCtx->pzScan[ res_len ] = NUL;
 
     /*
@@ -544,7 +544,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
                 /*
                  *  Return the keyword token code instead of DP_EV_NAME
                  */
-                *pRetVal = aKeywordTkn[ kw_ix ];
+                *pRetVal = (te_dp_event)aKeywordTkn[ kw_ix ];
                 break;
             }
         } while (++kw_ix < KEYWORD_CT);
