@@ -1,7 +1,7 @@
 /*  -*- Mode: C -*-
  *
  *  expExtract.c
- *  $Id: expExtract.c,v 4.5 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: expExtract.c,v 4.8 2005/12/13 20:07:29 bkorb Exp $
  *  This module implements a file extraction function.
  */
 
@@ -136,25 +136,21 @@ static SCM
 buildEmptyText( const char* pzStart, const char* pzEnd,
                 SCM def )
 {
-    size_t mlen = strlen( pzStart ) + strlen( pzEnd );
-    SCM res;
-    char* pzDef;
-    size_t dlen;
+    size_t mlen = strlen( pzStart ) + strlen( pzEnd ) + 3;
+    char* pzOut;
 
-    if (! gh_string_p( def ))
-        dlen = 0;
+    if (! AG_SCM_STRING_P( def )) {
+        pzOut = ag_scribble( mlen );
+        sprintf( pzOut, "%s\n%s", pzStart, pzEnd );
 
-    else {
-        dlen = SCM_LENGTH( def ) + 1;
-        pzDef = ag_scm2zchars( def, "default extract string" );
+    } else {
+        char* pzDef = ag_scm2zchars( def, "default extract string" );
+        mlen += AG_SCM_STRLEN( def ) + 1;
+        pzOut = ag_scribble( mlen );
+        sprintf( pzOut, "%s\n%s\n%s", pzStart, pzDef, pzEnd );
     }
 
-    res = scm_makstr( mlen + dlen + 1, 0 );
-    if (dlen > 0)
-         sprintf( SCM_CHARS( res ), "%s\n%s\n%s", pzStart, pzDef, pzEnd );
-    else sprintf( SCM_CHARS( res ), "%s\n%s", pzStart, pzEnd );
-
-    return res;
+    return AG_SCM_STR02SCM( pzOut );
 }
 
 
@@ -167,7 +163,6 @@ extractText( const char* pzText, const char* pzStart, const char* pzEnd,
 {
     const char* pzS = strstr( pzText, pzStart );
     const char* pzE;
-    SCM res;
 
     if (pzS == NULL)
         return buildEmptyText( pzStart, pzEnd, def );
@@ -177,10 +172,8 @@ extractText( const char* pzText, const char* pzStart, const char* pzEnd,
         return buildEmptyText( pzStart, pzEnd, def );
 
     pzE += strlen( pzEnd );
-    res = scm_makstr( pzE - pzS, 0 );
-    memcpy( SCM_CHARS( res ), pzS, pzE - pzS );
 
-    return res;
+    return AG_SCM_STR2SCM( pzS, pzE - pzS );
 }
 
 
@@ -219,6 +212,7 @@ extractText( const char* pzText, const char* pzStart, const char* pzEnd,
  *      is found, then this text will be inserted between the START and END
  *      markers.
  * @end itemize
+ *
  * @noindent
  * The resulting strings are presumed to be unique within
  * the subject file.  As a simplified example:
@@ -235,6 +229,7 @@ extractText( const char* pzText, const char* pzStart, const char* pzEnd,
  * example default
  * // END   - SOMETHING - DO NOT CHANGE THIS COMMENT
  * @end example
+ *
  * @noindent
  * The ``@code{example default}'' string can then be carried forward to
  * the next generation of the output, @strong{@i{provided}} the output
@@ -268,7 +263,7 @@ ag_scm_extract( SCM file, SCM marker, SCM caveat, SCM def )
     const char* pzEnd;
     const char* pzText;
 
-    if (! gh_string_p( file ) || ! gh_string_p( marker ))
+    if (! AG_SCM_STRING_P( file ) || ! AG_SCM_STRING_P( marker ))
         return SCM_UNDEFINED;
 
     pzText = loadExtractData( ag_scm2zchars( file, "extract file" ));
@@ -277,7 +272,7 @@ ag_scm_extract( SCM file, SCM marker, SCM caveat, SCM def )
         const char* pzMarker = ag_scm2zchars( marker, "extract marker" );
         const char* pzCaveat = "DO NOT CHANGE THIS COMMENT";
 
-        if (gh_string_p( caveat ) && (SCM_LENGTH( caveat ) > 0))
+        if (AG_SCM_STRING_P( caveat ) && (AG_SCM_STRLEN( caveat ) > 0))
             pzCaveat = ag_scm2zchars( caveat, "extract caveat" );
 
         pzStart = aprf( pzMarker, "START", pzCaveat );
@@ -316,7 +311,7 @@ ag_scm_find_file( SCM file, SCM suffix )
     tSCC  zFun[] = "ag_scm_find_file";
     SCM res = SCM_UNDEFINED;
 
-    if (! gh_string_p( file ))
+    if (! AG_SCM_STRING_P( file ))
         scm_wrong_type_arg( zFun, 1, file );
 
     {
@@ -326,15 +321,15 @@ ag_scm_find_file( SCM file, SCM suffix )
         /*
          *  The suffix is optional.  If provided, it will be a string.
          */
-        if (gh_string_p( suffix )) {
+        if (AG_SCM_STRING_P( suffix )) {
             char* apz[2];
             apz[0] = ag_scm2zchars( suffix, "file suffix" );
             apz[1] = NULL;
             if (SUCCESSFUL( findFile( pz, z, (tCC**)apz )))
-                res = gh_str02scm( z );
+                res = AG_SCM_STR02SCM( z );
 
         } else if (SUCCESSFUL( findFile( pz, z, NULL )))
-            res = gh_str02scm( z );
+            res = AG_SCM_STR02SCM( z );
     }
 
     return res;
