@@ -1,5 +1,5 @@
 /*
- *  $Id: expGperf.c,v 4.5 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: expGperf.c,v 4.6 2005/12/04 22:26:21 bkorb Exp $
  *  This module implements the expression functions that should
  *  be part of Guile.
  */
@@ -116,11 +116,11 @@ tSCC zRunGperf[] = "${gperf_%s} %s";
 SCM
 ag_scm_make_gperf( SCM name, SCM hlist )
 {
-    SCM     newline  = gh_str2scm( "\n", 1 );
+    SCM     newline  = AG_SCM_STR2SCM( "\n", 1 );
     char*   pzName   = ag_scm2zchars( name, "gperf name" );
     char*   pzList;
 
-    if (! gh_string_p( name ))
+    if (! AG_SCM_STRING_P( name ))
         return SCM_UNDEFINED;
 
     /*
@@ -191,7 +191,7 @@ ag_scm_gperf( SCM name, SCM str )
     if (*pzStr == NUL)
         str = SCM_UNDEFINED;
     else
-        str = gh_str02scm( pzStr );
+        str = AG_SCM_STR02SCM( pzStr );
 
     AGFREE( pzCmd );
     AGFREE( pzStr );
