@@ -2,7 +2,7 @@
 /*  -*- Mode: C -*-
  *
  *  expMake.c
- *  $Id: expMake.c,v 4.3 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: expMake.c,v 4.4 2005/12/04 22:26:21 bkorb Exp $
  *  This module implements Makefile construction functions.
  */
 
@@ -117,7 +117,7 @@ ag_scm_makefile_script( SCM text )
     }
 
     if (*pzText == NUL)
-        return gh_str02scm( "" );
+        return AG_SCM_STR02SCM( "" );
 
     {
         char*  pz  = strchr( pzText, '\n' );
@@ -255,11 +255,7 @@ ag_scm_makefile_script( SCM text )
         } copy_done:;
 
         sz    = (pzOut - pzRes);
-        res   = scm_makstr( sz, 0 );
-        pzOut = SCM_CHARS( res );
-
-        memcpy( pzOut, pzRes, sz );
-
+        res   = AG_SCM_STR2SCM( pzRes, sz );
         AGFREE( pzRes );
     }
 
