@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun Apr 24 17:48:42 PDT 2005
+ * Generated Thu Dec 15 15:11:44 PST 2005
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD
@@ -40,9 +40,6 @@ openServer( tFdPair* pPair, tCC** ppArgs );
 LOCAL pid_t
 openServerFP( tpfPair* pfPair, tCC** ppArgs );
 
-LOCAL char*
-loadData( FILE* fp );
-
 LOCAL char*
 runShell( const char*  pzCmd );
 
@@ -56,7 +53,7 @@ LOCAL void
 doOptions( int arg_ct, char** arg_vec );
 
 LOCAL tCC*
-getDefine( tCC* pzDefName );
+getDefine( tCC* pzDefName, ag_bool check_env );
 
 LOCAL char*
 spanQuote( char* pzQte );
@@ -119,15 +116,6 @@ findPlace( char* name, tCC* pzIndex );
 LOCAL void
 readDefines( void );
 
-/*
- *  Extracted from expExtract.c
- */
-/*
- *  Extracted from expFormat.c
- */
-/*
- *  Extracted from expGperf.c
- */
 /*
  *  Extracted from expGuile.c
  */
@@ -137,9 +125,6 @@ gh_type_e( SCM typ );
 LOCAL SCM
 ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line );
 
-/*
- *  Extracted from expMake.c
- */
 /*
  *  Extracted from expOutput.c
  */
@@ -152,18 +137,6 @@ removeWriteAccess( int fd );
 LOCAL SCM
 run_printf( char* pzFmt, int len, SCM alist );
 
-/*
- *  Extracted from expState.c
- */
-/*
- *  Extracted from expString.c
- */
-/*
- *  Extracted from fmemopen.c
- */
-/*
- *  Extracted from funcCase.c
- */
 /*
  *  Extracted from funcDef.c
  */
@@ -182,15 +155,6 @@ evalExpression( ag_bool* pMustFree );
 LOCAL SCM
 eval( const char* pzExpr );
 
-/*
- *  Extracted from funcFor.c
- */
-/*
- *  Extracted from funcIf.c
- */
-/*
- *  Extracted from functions.c
- */
 /*
  *  Extracted from loadPseudo.c
  */
@@ -200,9 +164,6 @@ doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo );
 LOCAL tCC*
 loadPseudoMacro( tCC* pzData, tCC* pzFileName );
 
-/*
- *  Extracted from opts.c
- */
 /*
  *  Extracted from tpLoad.c
  */
@@ -215,9 +176,6 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList );
 LOCAL tTemplate*
 templateFixup( tTemplate* pTList, size_t ttlSize );
 
-LOCAL void
-mapDataFile( tCC* pzFileName, tMapInfo* pMapInfo, tCC** papSuffixList );
-
 LOCAL tTemplate*
 loadTemplate( tCC* pzFileName );
 
