@@ -1,7 +1,7 @@
 
 /*
- *  $Id: putshell.c,v 4.6 2005/06/07 22:26:44 bkorb Exp $
- * Time-stamp:      "2005-02-14 14:55:01 bkorb"
+ *  $Id: putshell.c,v 4.8 2005/12/13 20:07:29 bkorb Exp $
+ * Time-stamp:      "2005-12-13 10:28:47 bkorb"
  *
  *  This module will interpret the options set in the tOptions
  *  structure and print them to standard out in a fashion that
@@ -65,7 +65,7 @@ static void
 putQuotedStr( tCC* pzStr )
 {
     /*
-     *  Handle empty strings to make the rese of the logic simpler.
+     *  Handle empty strings to make the rest of the logic simpler.
      */
     if ((pzStr == NULL) || (*pzStr == NUL)) {
         fputs( "''", stdout );
@@ -200,7 +200,7 @@ optionPutShell( tOptions* pOpts )
                     else if (ch == NUL)      { pz--; goto name_done; }
                     else fputc( '_', stdout );
                 } name_done:;
-                printf( "=%1$d # 0x%1$X\n", val );
+                printf( "=%1$ld # 0x%1$lX\n", val );
                 val <<= 1;
             }
             free( (void*)(pOD->pzLastArg) );
