@@ -1,11 +1,11 @@
 
 /*
  *  columns.c
- *  $Id: columns.c,v 4.1 2005/01/01 00:12:38 bkorb Exp $
+ *  $Id: columns.c,v 4.6 2005/11/07 00:22:05 bkorb Exp $
  */
 
 /*
- *  Columns copyright 1992-2004 Bruce Korb
+ *  Columns copyright 1992-2005 Bruce Korb
  *
  *  Columns is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -20,8 +20,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with Columns.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 #ifndef NUL
 # define NUL '\0'
@@ -34,9 +34,6 @@ struct print_list {
 
 typedef struct print_list tPrintList, *tpPrintList;
 
-typedef int (tCompProc)(const void*, const void*);
-tCompProc compProc;
-
 int maxEntryWidth = 0;
 int fillColumnCt  = 0;
 
@@ -52,11 +49,23 @@ size_t  lineWidth  = 79;
 size_t  columnCt   = 0;
 size_t  columnSz   = 0;
 
-void readLines( void );
-void writeRows( void );
-void writeColumns( void );
-int  handleIndent( tCC* pzIndentArg );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static int
+handleIndent( tCC* pzIndentArg );
 
+static void
+readLines( void );
+
+static void
+writeColumns( void );
+
+static void
+writeRows( void );
+
+static int
+compProc( const void* p1, const void* p2 );
+/* = = = END-STATIC-FORWARD = = = */
 
 int
 main( int    argc,
@@ -83,7 +92,7 @@ main( int    argc,
              *  Compute it, but do not let it be larger than
              *  the indentation value.
              */
-            tCC*   pzSave = pzLinePfx;
+            tCC* pzSave = pzLinePfx;
             size_t firstSize = handleIndent( OPT_ARG( FIRST_INDENT ));
             pzFirstPfx = pzLinePfx;
             pzLinePfx  = pzSave;
@@ -136,7 +145,7 @@ main( int    argc,
 }
 
 
-int
+static int
 handleIndent( tCC* pzIndentArg )
 {
     char* pz;
@@ -214,7 +223,7 @@ handleIndent( tCC* pzIndentArg )
 }
 
 
-void
+static void
 readLines( void )
 {
     int   sepLen;
@@ -365,7 +374,7 @@ readLines( void )
 }
 
 
-void
+static void
 writeColumns( void )
 {
     char zFmt[ 12 ];
@@ -508,7 +517,7 @@ writeColumns( void )
 }
 
 
-void
+static void
 writeRows( void )
 {
     char zFmt[ 12 ];
@@ -593,7 +602,7 @@ writeRows( void )
 /*
  *  Line comparison procedure
  */
-int
+static int
 compProc( const void* p1, const void* p2 )
 {
     const char* pz1 = *(char* const*)p1;
