@@ -1,7 +1,7 @@
 
 /*
  *  xml2ag.c
- *  $Id: xml2ag.c,v 4.4 2005/01/24 00:00:58 bkorb Exp $
+ *  $Id: xml2ag.c,v 4.6 2005/11/07 00:22:05 bkorb Exp $
  *  This is the main routine for xml2ag.
  *
  *  xml2ag copyright 2002-2005 Bruce Korb
@@ -19,8 +19,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 tSCC zConflict[] =
@@ -84,14 +84,14 @@ printChildren( xmlNodePtr pNode );
 /* = = = END-STATIC-FORWARD = = = */
 #define TRIM(s,psz) trim( (const char*)(s), (size_t*)(psz) )
 
-extern void forkAutogen( tCC* pzInput );
+extern void forkAutogen( const char* pzInput );
 
 
 int
 main( int argc, char** argv )
 {
-    xmlDocPtr pDoc;
-    tCC*      pzFile = NULL;
+    xmlDocPtr   pDoc;
+    const char* pzFile = NULL;
 
     {
         int ct = optionProcess( &xml2agOptions, argc, argv );
@@ -281,7 +281,7 @@ static xmlNodePtr
 printHeader( xmlDocPtr pDoc )
 {
     tSCC zDef[] = "AutoGen Definitions %s%s;\n";
-    tCC* pzSfx = ".tpl";
+    const char* pzSfx = ".tpl";
 
     xmlNodePtr pRootNode = xmlDocGetRootElement( pDoc );
     xmlChar*   pTpl = NULL;
